from setuptools import setup, find_packages

setup(
    name='crmchatbot',  
    version='0.1.4',
    author='AseelWajieh',
    author_email='aseel.wajieh@gmail.com',
    description='A package for a crm chatbot that can answer user requests if it was related to crm data, and fetch some data based on the user request.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'aiohttp==3.9.3',
        'aiosignal==1.3.1',
        'annotated-types==0.6.0',
        'anyio==4.3.0',
        'attrs==23.2.0',
        'certifi==2024.2.2',
        'charset-normalizer==3.3.2',
        'dataclasses-json==0.6.4',
        'distro==1.9.0',
        'fastapi==0.110.0',
        'frozenlist==1.4.1',
        'h11==0.14.0',
        'httpcore==1.0.4',
        'httpx==0.27.0',
        'idna==3.6',
        'jsonpatch==1.33',
        'jsonpointer==2.4',
        'langchain==0.1.9',
        'langchain-community==0.0.24',
        'langchain-core==0.1.27',
        'langchain-openai==0.0.8',
        'langsmith==0.1.10',
        'marshmallow==3.21.0',
        'multidict==6.0.5',
        'mypy-extensions==1.0.0',
        'numpy==1.26.4',
        'openai==1.12.0',
        'orjson==3.9.15',
        'packaging==23.2',
        'pydantic==2.6.3',
        'pydantic_core==2.16.3',
        'python-dotenv==1.0.1',
        'PyYAML==6.0.1',
        'regex==2023.12.25',
        'requests==2.31.0',
        'sniffio==1.3.1',
        'SQLAlchemy==2.0.27',
        'starlette==0.36.3',
        'tenacity==8.2.3',
        'tiktoken==0.6.0',
        'tqdm==4.66.2',
        'typing-inspect==0.9.0',
        'typing_extensions==4.10.0',
        'urllib3==2.2.1',
        'yarl==1.9.4'],
    url='https://github.com/aseelwajieh/CRM-package',
)

